@@ -28,7 +28,7 @@
 #include <utilxml.h>
 
 //KDE includes
-#include <klocale.h>
+#include <tdelocale.h>
 
 //TQt includes
 #include <tqstring.h>
@@ -72,7 +72,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 		sword::SWModule* myModule = const_cast<sword::SWModule*>(myUserData->module); //hack
 
 		XMLTag tag(token);
-		//     qWarning("found %s", token);
+		//     tqWarning("found %s", token);
 		const bool osisTQToTick = ((!userData->module->getConfigEntry("OSISqToTick")) || (strcmp(userData->module->getConfigEntry("OSISqToTick"), "false")));
 
 		if (!tag.getName()) {
@@ -285,14 +285,14 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 					myUserData->noteType = BT_UserData::StrongsMarkup;
 				}
 				else if (type == "alternative") {
-					//      qWarning("found alternative");
+					//      tqWarning("found alternative");
 					//       buf.append(" <span class=\"alternative\">");
 					myUserData->noteType = BT_UserData::Alternative;
 					myUserData->suspendTextPassThru = true;
 					myUserData->swordFootnote++; // count as notes, too
 				}
 				else {
-					//           qWarning("found note in %s", myUserData->key->getShortText());
+					//           tqWarning("found note in %s", myUserData->key->getShortText());
 					buf.append(" <span class=\"footnote\" note=\"");
 					buf.append(myModule->Name());
 					buf.append('/');
@@ -599,7 +599,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
 			else { // seg end tag
 				buf.append("</span>");
 			}
-			//qWarning(TQString("handled <seg> token. result: %1").arg(buf.c_str()).latin1());
+			//tqWarning(TQString("handled <seg> token. result: %1").arg(buf.c_str()).latin1());
 		}
 		
 		//divine name, don't use simple tag replacing because it may have attributes
