@@ -37,9 +37,9 @@
 #include <tqmessagebox.h>
 
 //KDE includes
-#include <kapplication.h>
-#include <kfiledialog.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdefiledialog.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 
 namespace Search {
@@ -83,7 +83,7 @@ void CSearchAnalysisDialog::initView() {
 	TQVBoxLayout* layout = new TQVBoxLayout(plainPage(),0);
 
 	TQPushButton* button = new TQPushButton(plainPage(), "button");
-	button->setIconSet(SmallIconSet("filesave"));
+	button->setIconSet(SmallIconSet("document-save"));
 	button->setText(i18n("Save search analysis as HTML"));
 	button->setFixedSize(button->sizeHint());
 	layout->addWidget(button);
@@ -160,7 +160,7 @@ void CSearchAnalysis::analyse(ListCSwordModuleInfo modules) {
 		moduleIndex = 0;
 		ListCSwordModuleInfo::iterator end_it = m_moduleList.end();
 		for (ListCSwordModuleInfo::iterator it(m_moduleList.begin()); it != end_it; ++it) {
-			KApplication::kApplication()->processEvents( 10 ); //10 ms only
+			TDEApplication::kApplication()->processEvents( 10 ); //10 ms only
 			if (!m_lastPosList.contains(*it)) {
 				m_lastPosList.insert(*it,0);
 			}
@@ -585,3 +585,5 @@ void CSearchAnalysis::saveAsHTML() {
  
 	} //end of namespace Search::Analysis
 } //end of namespace Search
+
+#include "csearchanalysis.moc"
